(* $Id: test_img.ml,v 1.5 2014/02/27 16:36:36 fclement Exp $ *)

(* Array auxiliaries. *)
let sub_matrix_iter_i_j f m lstart cstart nl nc =
 (* Should verify the correctness of the sub matrix specification ???
    for the time being the sub matrix is cropped inside the original matrix. *)
 let lstart = max 0 lstart
 and cstart = max 0 cstart in

 let lstop  = min (lstart + nl) (Array.length m - 1) in
 for i = lstart to lstop do
  let line = m.(i) in
  let cstop = min (cstart + nc) (Array.length line - 1) in
  for j = cstart to cstop do f i j line.(j) done
 done
;;

let sub_matrix_iter f m = sub_matrix_iter_i_j (fun _ _ v -> f v) m;;

let matrix_iter_i_j f m = sub_matrix_iter_i_j f m 0 0 max_int max_int;;
let matrix_iter f m = sub_matrix_iter f m 0 0 max_int max_int;;

(* Graphics auxiliaries. *)
open Graphics;;

let get_color, set_color =
  let current_color = ref foreground in
  (function () -> !current_color),
  (function c -> current_color := c; Graphics.set_color c);;

let set_foreground = set_color;;

let set_background c =
  set_color c;
  fill_rect 0 0 (size_x ()) (size_y ());
  set_color (get_color ())
;;

(* The test *)
let sz = 450;;
let sz_x = sz;;
let sz_y = sz;;

open_graph (Printf.sprintf " %dx%d" sz_x sz_y);;

set_foreground black
;;
set_background white
;;

let draw_image_from_graphics x y w h img =
 let plot_point i j c = set_color c; plot (x + j) (y + i) in
 sub_matrix_iter_i_j plot_point img h w
;;

let get_image_from_graphics x y w h =
  (* Valid x, y, w, h. *)
  let maxx = x + w and maxy = y + h in
  if maxx > size_x () || maxx < 0 ||
     maxy > size_y () || maxy < 0 then
    invalid_arg "get_image_from_graphics:" else
  let img = Array.init h (fun l -> Array.init w (fun c -> white)) in
  for i = 0 to h - 1 do
    for j = 0 to w - 1 do
      img.(i).(j) <- point_color (x + j) (y + i)
    done
  done;
  img
;;

let gimg = get_image_from_graphics 0 0 97 103;;
let dimg = let img = get_image 0 0 97 103 in
dump_image img
;;

let verify_img f img =
  let verify i j c =
    if not (f c) then failwith (Printf.sprintf
      "Point (%i, %i) should not have color %i" i j c) in
  matrix_iter_i_j verify img
;;

verify_img (fun c -> c = white) gimg
;;
verify_img (fun c -> c = white) dimg
;;

(*open Ppm;;

save_ppm_file "test.ppm" dimg
;;

let ppm = load_ppm_file "test.ppm";;
*)
