#######################################################################
#                                                                     #
#                                 Pph                                 #
#                                                                     #
#                    The Portable Project Handler                     #
#                                                                     #
#               EPI Pomdapi, INRIA Paris - Rocquencourt               #
#                                                                     #
#  Copyright 2005-2014 INRIA.                                         #
#  Institut National de Recherche en Informatique et en Automatique.  #
#  All rights reserved. This file is distributed only by permission.  #
#                                                                     #
#  Francois Clement <Francois.Clement@inria.fr>                       #
#  Pierre Weis <Pierre.Weis@inria.fr>                                 #
#                                                                     #
#######################################################################

# $Id: basic_commands.profile,v 1.32 2014/01/31 13:35:10 fclement Exp $

#
# Pph system basic commands for generic scripts.
#

AR_COMMAND="ar"
AS_COMMAND="as"
AWK="awk"

BASENAME="basename"
BH="${PPH_SYSTEM_ROOT_DIR}/private/bin/bh"

CAT="cat"
CHMOD="chmod -Rf"
CLEAR="clear"
CMP="cmp -s"
CP_COMMAND="cp -Rfp"
CUT="cut"
CVS_ROOT_FILE="CVS/Root"
PROJECT_ROOT_CVS_ROOT_FILE="${PROJECT_ROOT_DIR}/${CVS_ROOT_FILE}"
PROJECT_CVS_ROOT="`if test -f ${PROJECT_ROOT_CVS_ROOT_FILE}; then            cat ${PROJECT_ROOT_CVS_ROOT_FILE};          else            echo "Error: no CVS root file found." &&            exit ${NONEXISTENT_FILE_ERROR};          fi`"
CVS="cvs -fqw"
SAFE_CVS="cvs -d ${PROJECT_CVS_ROOT} -fqw"

DATE="date"
DIFF="diff"
DIRNAME="dirname"

ECHO="echo"

FIND="find"

GREP="grep"
GUNZIP="gunzip -f"
GZIP="gzip -cf"

HEAD="head -n"
HTMLC_COMPILER="${PPH_SYSTEM_ROOT_DIR}/private/bin/htmlc"

INSTALL="install"

# Do not use the -f option of the ln command since it is not safe.
# Instead, always issue an rm command before any use of ln.
# Furthermore, apparently on some old SunOS system, it meant "hard link".
LN="ln -s"
LS="ls"

MAIL="mail -n"
MAKE_COMMAND="make"
MAN="man"
MD5SUM="md5sum"
MKDIR="mkdir -p"
MKTEMP="mktemp"
MV="mv -f"

PASTE="paste"
PHM="phm"
PPA="${PPH_SYSTEM_ROOT_DIR}/private/bin/ppa"

REALPATH="realpath -s"
RM="rm -fr"
RMDIR="rmdir"

SCP="scp"
SED="sed"
SH="/bin/sh"
SLEEP="sleep"
SORT="sort"
SSH="ssh"
SVN="svn"

TAIL="tail"
TAR="tar"
TEE="tee"
TOUCH="touch"
TR="tr"
TYPE="type"

UNAME="uname"

WC="wc"

XARGS="xargs"

YES="yes"

ZCAT="zcat -f"
ZIP="zip -qr"

#
# Standard uses.
#

CHMOD_EXECUTABLE="${CHMOD} +x"
CHMOD_READ_ONLY="${CHMOD} -w"
CHMOD_WRITABLE="${CHMOD} +w"
CP="${CP_COMMAND} -L"
CP_DONT_FOLLOW_LINKS="${CP_COMMAND} -P"
CP_FOLLOW_GIVEN_LINKS="${CP_COMMAND} -H"
GET_FIRST_CHARACTER="${CUT} -c 1"
FIRST_ITEM_SPACE_SEPARATED="${CUT} -d ' ' -f 1"
SECOND_ITEM_SPACE_SEPARATED="${CUT} -d ' ' -f 2"
FIRST_ITEM_DOT_SEPARATED="${CUT} -d . -f 1"
SECOND_ITEM_DOT_SEPARATED="${CUT} -d . -f 2"
CVS_ADD="${CVS} add"
CVS_CHECKOUT="${SAFE_CVS} checkout -PR"
CVS_COMMIT="${CVS} commit -R"
CVS_EXPORT="${SAFE_CVS} export -R"
CVS_IMPORT="${SAFE_CVS} import -I \*~"
CVS_LOCK="${CVS} watch add -R -a all"
CVS_REMOVE="${CVS} remove -Rf"
CVS_RTAG="${SAFE_CVS} rtag -R"
CVS_TAG="${CVS} tag -R"
CVS_UNLOCK="${CVS} watch remove -R -a all"
CVS_UNRTAG="${SAFE_CVS} rtag -Rd"
CVS_UNTAG="${CVS} tag -Rd"
CVS_UPDATE="${CVS} update -PRd"
CVS_BRANCH="${CVS_RTAG} -b"
CVS_EXPORT_HEAD_TRUNK="${CVS_EXPORT} -r HEAD"
CVS_MERGE="${CVS_UPDATE} -kk"
CVS_UNBRANCH="${CVS_UNRTAG} -B"
CVS_UPDATE_HEAD_TRUNK="${CVS_UPDATE} -A"

FULL_DATE="${DATE} +%y%m%d%H%M%S"
QUIET_DIFF="${DIFF} -qr"
DIFF_TWO_COLUMNS="${DIFF} --side-by-side --suppress-common-lines"

EGREP="${GREP} -E"
EGREPV="${EGREP} -v"

FINDH="${FIND} -H"

GNU_MAKE_GAG_FILTER="${EGREPV} '^g?make\[[1-9][0-9]*\]: '"

HTMLC_FILTER="${HTMLC_COMPILER} -from - -to -"

IDENTITY_FILTER="${TEE}"
INSTALL_EXECUTABLE="${INSTALL} -m 0555"
INSTALL_READ_ONLY="${INSTALL} -m 0444"

LA="${LS} -a"
LD="${LS} -d"
LF="${LS} -F"
LL="${LA} -l"
LLD="${LD} -l"
LX="${LS} -x"

MK_LIST="${TR} -s '[:space:]' \\040"
MK_TEMP_DIR="${MKTEMP} -d /tmp/pph.XXXXXX"

BUMP_MAJOR_VERSION="${PPA} --bump-major-version"
BUMP_MINOR_VERSION="${PPA} --bump-minor-version"
BUMP_LEVEL_TYPE="${PPA} --bump-level-type"
BUMP_LEVEL_VALUE="${PPA} --bump-level-value"
PRINT_HIERARCHY_CONTENTS="${AWK} -f ${PPH_USER_SCRIPTS_DIR}/print_hierarchy_contents.awk"

REVERT_LIST="${AWK} -f ${PPH_USER_SCRIPTS_DIR}/revert_list.awk"
RMDIR_AND_PARENTS="${RMDIR} -p"

SORTR="${SORT} -r"
SORT_HIERARCHY_CONTENTS="${SORT} -k 2"
SORT_UNIQUE="${SORT} -u"
STRIP_NEWLINE="${TR} -d '\n'"
STRIP_SPACE="${TR} -d '[:space:]'"
SVN_ADD="${SVN} add"
SVN_CHECKOUT="${SVN} checkout"
SVN_COMMIT="${SVN} commit"
SVN_COPY="${SVN} copy"
SVN_DELETE="${SVN} delete"
SVN_EXPORT="${SVN} export"
SVN_ID="${SVN} propset svn:keywords Id"
SVN_IGNORE="${SVN} propset svn:ignore"
SVN_IMPORT="${SVN} import"
SVN_LOCK="${SVN} lock"
SVN_MERGE="${SVN} merge"
SVN_UNLOCK="${SVN} unlock"
SVN_UPDATE="${SVN} update"
SVN_BRANCH="${SVN_COPY}"

TAKE_A_SHORT_NAP="${SLEEP} 1"
TARC="${TAR} -cf"
TARCH="${TAR} -chf"
TARCV="${TAR} -cvf"
TARCZ="${TAR} -cvzf"
TARX="${TAR} -xf"
TARXV="${TAR} -xvf"
TARXZ="${TAR} -xzf"
TARXP="${TAR} -xpf"
TARXPV="${TAR} -xpvf"
TARXPZ="${TAR} -xpvzf"
TEE_APPEND="${TEE} -a"
TOUCHC="${TOUCH} -c"

GET_MACHINE_HARDWARE_NAME="${UNAME} -m"

WC_CHAR="${WC} -c"
WC_BYTE="${WC} -m"
WC_LINE="${WC} -l"
WC_WORD="${WC} -w"
